@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 (* Import from Cil *)
 open Cil_types
@@ -40,6 +40,9 @@ open Visitor
 (* Utility functions *)
 open Format
 
+let constant_expr ?(loc=Cil_datatype.Location.unknown) e = 
+  Ast_info.constant_expr ~loc e
+
 exception NotImplemented of string
 exception Unsupported of string
 
@@ -232,8 +235,11 @@ let name_of_integral_type ?bitsize ty =
 
 let arraylen_attr_name = "arraylen"
 
-let mkTRef elemty =
+let mkTRef elemty _msg =
   (* Define the same arguments as for [mkTRefArray] *)
+(*
+  Format.eprintf "mkTRef, coming from %s@." msg;
+*)
   let size = constant_expr 1L and attr = [] in
   (* Do the same as in [mkTRefArray] *)
   let siz = expToAttrParam size in
@@ -254,7 +260,11 @@ let mkTRefArray (elemty,size,attr) =
 
 let reference_size ty =
   match findAttribute arraylen_attr_name (typeAttrs ty) with
-    | [AInt i] -> Int64.of_int i
+    | [AInt i] -> 
+(*
+        eprintf "AInt has argument %d@." i;
+*)
+        Int64.of_int i
     | _ -> assert false
 
 let is_reference_type ty =
@@ -350,9 +360,9 @@ let name_of_realloc = "realloc"
 
 let predefined_name =
   [ (* coding functions *)
-    name_of_assert; 
-    name_of_malloc; 
-    name_of_calloc; 
+    name_of_assert;
+    name_of_malloc;
+    name_of_calloc;
     name_of_realloc;
     name_of_free;
   ]
@@ -378,20 +388,20 @@ let unique_name_generator is_exception =
 	if Hashtbl.mem unique_names s then
 	  aux s
 	else
-	  (Hashtbl.add unique_names s (ref 0); 
+	  (Hashtbl.add unique_names s (ref 0);
 	   incr count; s)
       with Not_found ->
 	Hashtbl.add unique_names s (ref 0); s
-  in 
+  in
   let add s = Hashtbl.add unique_names s (ref 0) in
   aux, add
 
 let unique_name, add_unique_name =
-(*  let u = *)unique_name_generator is_predefined_name 
+(*  let u = *)unique_name_generator is_predefined_name
 (* in (fun s -> let s' = u s in s') *)
 
 let unique_logic_name, add_unique_logic_name =
-(*  let u = *) unique_name_generator (fun _ -> false) 
+(*  let u = *) unique_name_generator (fun _ -> false)
 (* in (fun s -> let s' = u s in s')*)
 
 let unique_name_if_empty s =
@@ -484,7 +494,6 @@ let name_of_safety_behavior = "safety"
 
 let name_of_default_behavior = "default"
 
-
 (*****************************************************************************)
 (* Visitors                                                                  *)
 (*****************************************************************************)
@@ -658,7 +667,7 @@ object
   method vassigns = visitor#vassigns
   method vloop_pragma = visitor#vloop_pragma
   method vslice_pragma = visitor#vslice_pragma
-  method vzone = visitor#vzone
+  method vdeps = visitor#vdeps
   method vcode_annot = visitor#vcode_annot
   method vannotation = visitor#vannotation
 
@@ -765,7 +774,7 @@ object
   method vassigns = visitor#vassigns
   method vloop_pragma = visitor#vloop_pragma
   method vslice_pragma = visitor#vslice_pragma
-  method vzone = visitor#vzone
+  method vdeps = visitor#vdeps
   method vcode_annot annot =
     Jessie_options.feedback "%a" !Ast_printer.d_code_annotation annot;
     visitor#vcode_annot annot
@@ -888,7 +897,7 @@ object(self)
   inherit Visitor.generic_frama_c_visitor
     (Project.current ()) (Cil.inplace_visit ()) as super
 
-  val known_fields = FieldinfoHashtbl.create 7
+  val known_fields = Cil_datatype.Fieldinfo.Hashtbl.create 7
 
   method vterm t =
     match t.term_node with
@@ -906,7 +915,7 @@ object(self)
     | Field(fi,_) ->
         begin
           try
-            if not (fi == FieldinfoHashtbl.find known_fields fi)
+            if not (fi == Cil_datatype.Fieldinfo.Hashtbl.find known_fields fi)
             then
 	      Jessie_options.warning ~current:true
 		"Field %s of type %s is not shared between declaration and use"
@@ -924,7 +933,7 @@ object(self)
     | TField(fi,_) ->
         begin
           try
-            if not (fi == FieldinfoHashtbl.find known_fields fi)
+            if not (fi == Cil_datatype.Fieldinfo.Hashtbl.find known_fields fi)
             then
               Jessie_options.warning ~current:true
 		"Field %s of type %s is not shared between declaration and use"
@@ -941,7 +950,7 @@ object(self)
   method vglob_aux = function
       GCompTag(c,_) ->
         List.iter
-          (fun x -> FieldinfoHashtbl.add known_fields x x) c.cfields;
+          (fun x -> Cil_datatype.Fieldinfo.Hashtbl.add known_fields x x) c.cfields;
         DoChildren
     | _ -> DoChildren
 
@@ -990,18 +999,16 @@ let mkpred pnode loc =
   }
 
 let mkInfo e =
-  match e.enode with Info _ -> e | _ ->
-    let einfo = {
-      exp_loc = locUnknown;
-      (* In many cases, the correct type may not be available, as
-       * the expression may result from a conversion from a term or a tset.
-       * Calling [typeOf] on such an expression may raise an error.
-       * Therefore, put here a dummy type until tsets correctly typed.
-       *)
-      exp_type = Ctype voidType; (* Ctype(typeOf e); *)
-      exp_name = [];
-    } in
-    new_exp (Info(e,einfo))
+  match e.enode with
+      Info _ -> e
+    | _ ->
+        let einfo = { exp_type = Ctype voidType; exp_name = [] } in
+        (* In many cases, the correct type may not be available, as
+         * the expression may result from a conversion from a term or a tset.
+         * Calling [typeOf] on such an expression may raise an error.
+         * Therefore, put here a dummy type until tsets correctly typed.
+         *)
+        new_exp ~loc:e.eloc (Info(e,einfo))
 
 (* Manipulation of offsets *)
 
@@ -1021,19 +1028,22 @@ let is_last_offset = function
  * same array that would be flattened to a single dimensional array.
  *)
 let rec lift_offset ty = function
-  | Index(idx1,(Index(_idx2, _off) as suboff)) ->
+  | Index(idx1,(Index(idx2, _off) as suboff)) ->
       let subty = direct_element_type ty in
       let siz = array_size subty in
       begin match lift_offset subty suboff with
 	| Index(idx, off) ->
-	    let mulidx = new_exp (BinOp(Mult,idx1,constant_expr siz,intType)) in
+	    let mulidx =
+              new_exp ~loc:idx2.eloc
+                (BinOp(Mult,idx1,constant_expr siz,intType)) in
 	    (* Keep info at top-level for visitors on terms that where
 	     * translated to expressions. Those expect these info when
 	     * translating back to term.
 	     *)
 	    let addidx =
-	      map_under_info (fun _e ->
-                                new_exp (BinOp(PlusA,mulidx,idx,intType))) idx1
+	      map_under_info
+                (fun e ->
+                   new_exp ~loc:e.eloc (BinOp(PlusA,mulidx,idx,intType))) idx1
 	    in
 	    Index(addidx,off)
 	| _ -> assert false
@@ -1045,7 +1055,10 @@ let rec lift_offset ty = function
 	(* Keep info at top-level *)
 	let mulidx =
 	  map_under_info
-	    (fun _e -> new_exp (BinOp(Mult,idx1,constant_expr siz,intType))) idx1
+	    (fun e ->
+               new_exp ~loc:e.eloc
+                 (BinOp(Mult,idx1,constant_expr siz,intType)))
+            idx1
 	in
 	Index(mulidx,NoOffset)
       else off
@@ -1053,7 +1066,7 @@ let rec lift_offset ty = function
 
 let change_idx idx1 idx siz =
   let boff =
-    Logic_utils.mk_dummy_term (TBinOp(Mult,idx1,constant_term locUnknown siz))
+    Logic_utils.mk_dummy_term (TBinOp(Mult,idx1,constant_term Cil_datatype.Location.unknown siz))
       intType
   in
   Logic_utils.mk_dummy_term (TBinOp(PlusA,boff,idx)) intType
@@ -1071,7 +1084,7 @@ let rec lift_toffset ty off =
         let subty = direct_element_type ty in
         if isArrayType subty then
           let siz = array_size subty in
-          TIndex(change_idx idx1 (constant_term locUnknown 0L) siz, TNoOffset)
+          TIndex(change_idx idx1 (constant_term Cil_datatype.Location.unknown 0L) siz, TNoOffset)
         else off
     | TIndex _ | TField _ | TNoOffset -> off
 
@@ -1087,13 +1100,15 @@ let malloc_function () =
 	(Ast.get ()) "malloc" (TFun(voidPtrType,params,false,[]))
     in
     let behav = {
-      b_name = name_of_default_behavior;
+      b_name = Cil.default_behavior_name;
       b_assumes = [];
+      b_requires = [];
+      b_extended = [];
+      b_assigns = Writes [];
       b_post_cond = [];
-      b_assigns = [ Nothing,[] ];
     } in
     let spec = { (empty_funspec ()) with spec_behavior = [behav]; } in
-    Globals.Functions.replace_by_declaration spec f locUnknown;
+    Globals.Functions.replace_by_declaration spec f Cil_datatype.Location.unknown;
     f
 
 let free_function () =
@@ -1106,24 +1121,27 @@ let free_function () =
 	(Ast.get ()) "free" (TFun(voidType,params,false,[]))
     in
     let behav = {
-      b_name = name_of_default_behavior;
+      b_name = Cil.default_behavior_name;
       b_assumes = [];
       b_post_cond = [];
-      b_assigns = [ Nothing,[] ];
-    } in
+      b_requires = [];
+      b_extended = [];
+      b_assigns = Writes [];
+    } 
+    in
     let spec = { (empty_funspec ()) with spec_behavior = [behav]; } in
-    Globals.Functions.replace_by_declaration spec f locUnknown;
+    Globals.Functions.replace_by_declaration spec f Cil_datatype.Location.unknown;
     f
 
 let mkalloc v ty loc =
-  let callee = new_exp (Lval(Var(malloc_function ()),NoOffset)) in
-  let arg = sizeOf ty in
+  let callee = new_exp ~loc (Lval(Var(malloc_function ()),NoOffset)) in
+  let arg = sizeOf ~loc ty in
   Call(Some(Var v,NoOffset),callee,[arg],loc)
 
 let mkalloc_statement v ty loc = mkStmt (Instr(mkalloc v ty loc))
 
 let mkalloc_array v ty num loc =
-  let callee = new_exp (Lval(Var(malloc_function ()),NoOffset)) in
+  let callee = new_exp ~loc (Lval(Var(malloc_function ()),NoOffset)) in
   let arg = constant_expr (Int64.mul num (Int64.of_int (sizeOf_int ty))) in
   Call(Some(Var v,NoOffset),callee,[arg],loc)
 
@@ -1131,8 +1149,8 @@ let mkalloc_array_statement v ty num loc =
   mkStmt (Instr(mkalloc_array v ty num loc))
 
 let mkfree v loc =
-  let callee = new_exp (Lval(Var(free_function ()),NoOffset)) in
-  let arg = new_exp (Lval(Var v,NoOffset)) in
+  let callee = new_exp ~loc (Lval(Var(free_function ()),NoOffset)) in
+  let arg = new_exp ~loc (Lval(Var v,NoOffset)) in
   Call(None,callee,[arg],loc)
 
 let mkfree_statement v loc = mkStmt (Instr(mkfree v loc))
