@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -96,7 +96,7 @@ let run () =
     File.create_project_from_visitor "jessie"
       (fun prj -> new Visitor.frama_c_copy prj)
   in
-  FCProject.copy ~only:(Plugin.get_selection ()) prj;
+  FCProject.copy ~selection:(Plugin.get_selection ()) prj;
   FCProject.set_current prj;
 
   let file = FCAst.get () in
@@ -250,9 +250,15 @@ let run () =
       Sys.chdir jessie_subdir;
 
 
+      let atp = Jessie_options.Atp.get () in
+      let jessie_opt = 
+	match atp with
+	  | "why3" | "why3ide" -> ""
+	  | _ -> "-why-opt -split-user-conj"
+      in
       let cmd =
 	make_command
-	  [ env_opt; jessie_cmd; "-why-opt -split-user-conj";
+	  [ env_opt; jessie_cmd; jessie_opt ;
 	    verbose_opt; why_opt; jc_opt; debug_opt; behav_opt;
 	    "-locs"; locname; filename ]
       in
@@ -268,7 +274,7 @@ let run () =
       *)
 
       Jessie_options.feedback "Calling VCs generator.";
-      sys_command (timeout ^ "make -f " ^ makefile ^ " " ^ (Jessie_options.Atp.get ()));
+      sys_command (timeout ^ "make -f " ^ makefile ^ " " ^ atp);
       flush_all ()
 
   with Exit -> ()
@@ -290,15 +296,15 @@ Please submit `feature request' report."
 	fatal
 	  "Unexpected failure.@\nPlease submit bug report (Ref. \"%s:%d:%d\")."
 	  file a b
-    | exn ->
+    (*| exn ->
 	fatal
 	  "Unexpected exception.@\nPlease submit bug report (Ref. \"%s\")."
 	  (Printexc.to_string exn)
-
+*)
 let run_and_catch_error =
   Dynamic.register
     "run_analysis"
-    (Type.func Type.unit Type.unit)
+    (Datatype.func Datatype.unit Datatype.unit)
     ~plugin:"Jessie"
     ~journalize:true
     run_and_catch_error
