@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -259,7 +259,7 @@ let select_obligs (model:GTree.tree_store) (tv:GText.view)
        let row = model#get_iter p in
        let s = model#get ~row ~column:Model.fullname in
        try
-	 let (loc,xpl,_,_) as o = Model.find_oblig s in
+	 let (loc,_,xpl,_,_) as o = Model.find_oblig s in
 	 let buf = update_buffer tv in
 	 buf#set_text "";
 	 Pprinter.text_of_obligation tv o;
@@ -390,7 +390,7 @@ let run_prover_child p (_view:GTree.view) (model:GTree.tree_store)
                      o bench alone = 
   let column_p = p.Model.pr_icon in
   let column_i = p.Model.pr_image in
-  let (_, _, oblig, seq) = o in
+  let (_, _, _, oblig, seq) = o in
   if bench or (try_proof seq) then
     try 
       let row = 
@@ -1176,7 +1176,7 @@ let main () =
     load_cache ();
     if not (Cache.is_empty ()) then 
       Hashtbl.iter 
-	(fun _s (_,_,o,seq) -> 
+	(fun _s (_,_,_,o,seq) -> 
 	   let cleaned = Cache.clean seq in
 	   if in_cache cleaned then begin 
 	     let row = Hashtbl.find Model.orows o in
