@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -50,7 +50,9 @@ let cvcl fmt f = fprintf fmt "cvcl/%s_why.cvc" f
 let harvey fmt f = fprintf fmt "harvey/%s_why.rv" f
 let zenon fmt f = fprintf fmt "zenon/%s_why.znn" f
 let smtlib fmt f = fprintf fmt "smtlib/%s_why.smt" f
+let smtlib_v1 fmt f = fprintf fmt "smtlib-v1/%s_why.smt" f
 let ergo fmt f = fprintf fmt "why/%s_why.why" f
+let gappa fmt f = fprintf fmt "gappa/%s_why.gappa" f
 let why_goals fmt f = fprintf fmt "why/%s_ctx.why" f
 let wpr fmt f = fprintf fmt "why/%s.wpr" f
 let isabelle fmt f = fprintf fmt "isabelle/%s_why.thy" f
@@ -96,8 +98,7 @@ let generic full f targets =
 
        out "coq/%s_why.v: WHYOPT=-coq -dir coq -coq-preamble \"Require Export jessie_why.\" -coq-tactic \"intuition\"@\n" f;
        out "coq/%s_why.v: why/%s.why@\n" f f;
-       out "\t@@echo 'why -coq [...] why/%s.why' && $(WHY) $(JESSIELIBFILES) why/%s.why@\n@\n" f f;
-
+       out "\t@@echo 'why -coq [...] why/%s.why' && $(WHY) $(JESSIELIBFILES) why/%s.why && rm -f coq/jessie_why.v@\n@\n" f f;
 
        out "coq-goals: goals coq/%s_ctx_why.vo@\n" f;
        out "\tfor f in why/*_po*.why; do make -f %s.makefile coq/`basename $$f .why`_why.v ; done@\n@\n" f;
@@ -109,7 +110,8 @@ let generic full f targets =
        out "coq/%%_why.v: WHYOPT=-no-pervasives -coq -dir coq -coq-preamble \"Require Export %s_ctx_why.\" -coq-tactic \"intuition\"@\n" f;
        out "coq/%%_why.v: why/%%.why@\n";
        out "\t@@echo 'why -coq [...] why/$*.why' && $(WHY) why/%s_ctx.why why/$*.why@\n@\n" f;
-       out "coq/%%.vo: coq/%%.v@\n\tcoqc -I coq $<@\n@\n";
+       out "coq/%%.vo: coq/%%.v@\n\tcoqc -I coq $<@\n";
+       out "coq/%%_po_why.vo: coq/%s_ctx_why.vo@\n@\n" f;
 
        out "pvs: %a@\n@\n" (print_files pvs) targets;
 
@@ -141,6 +143,12 @@ let generic full f targets =
        out "why/%%_why.why: why/%%.why@\n";
        out "\t@@echo 'why -alt-ergo [...] why/$*.why' && $(WHY) $(JESSIELIBFILES) why/$*.why@\n@\n";
 
+       out "gappa: %a@\n" (print_files gappa) targets;
+       out "\t@@echo 'Running Gappa on proof obligations' && ($(DP) $^)@\n@\n";
+       out "gappa/%%_why.gappa: WHYOPT=-gappa -dir gappa@\n";
+       out "gappa/%%_why.gappa: why/%%.why@\n";
+       out "\t@@echo 'why -gappa [...] why/$*.why' && $(WHY) $(JESSIELIBFILES) why/$*.why@\n@\n";
+
        out "cvcl: %a@\n@\n" (print_files cvcl) targets;
        out "\t@@echo 'Running CVC Lite on proof obligations' && ($(DP) $^)@\n@\n";
        out "cvcl/%%_why.cvc: WHYOPT=-cvcl -dir cvcl@\n";
@@ -174,24 +182,39 @@ let generic full f targets =
        out "cvc3: %a@\n" (print_files smtlib) targets;
        out "\t@@echo 'Running CVC3 on proof obligations' && ($(DP) -smt-solver cvc3 $^)@\n@\n";
 
+       out "smtlib-v1: %a@\n" (print_files smtlib_v1) targets;
+       out "smtlib-v1/%%_why.smt:  WHYOPT=-smtlib --smtlib-v1 --encoding sstrat --exp goal -dir smtlib-v1@\n";
+       out "smtlib-v1/%%_why.smt: why/%%.why@\n";
+       out "\t@@echo 'why -smtlib [...] why/$*.why' && $(WHY) $(JESSIELIBFILES) why/$*.why@\n@\n";
+
+       out "verit: %a@\n" (print_files smtlib_v1) targets;
+       out "\t@@echo 'Running VeriT on proof obligations' && ($(DP) -smt-solver verit $^)@\n@\n";
+
+
        out "gui stat: %s@\n"
 	 (match targets with f::_ -> f^".stat" | [] -> "");
        out "@\n";
        out "%%.stat: why/%%.why@\n";
        out "\t@@echo 'gwhy-bin [...] why/$*.why' && $(GWHY) $(JESSIELIBFILES) why/$*.why@\n@\n";
-       
 
-       out "why3: why/%s@\n"
-	 (match targets with f::_ -> f^"_why3.why" | [] -> "");
-       
+       let why3_target =
+	 (match targets with f::_ -> f^"_why3.why" | [] -> "")
+       in
+       out "why3: why/%s@\n" why3_target;
+
        out "why/%%_why3.why:  WHYOPT=-why3@\n";
        out "why/%%_why3.why: why/%%.why@\n";
        out "\t@@echo 'why -why3 [...] why/$*.why' \
             && $(WHY) $(JESSIELIBFILES) why/$*.why@\n";
 
+       out "why3ide: why/%s@\n" why3_target;
+       out "\t@@echo 'why3ide [...] $<' \
+            && why3ide $<@\n@\n";
+
        out "-include %s.depend@\n@\n" f;
        out "depend: %a@\n" (print_files coq_v) targets;
        out "\t-$(COQDEP) -I coq coq/%s*_why.v > %s.depend@\n@\n" f f;
+
        out "clean:@\n";
        out "\trm -f coq/*.vo@\n@\n";
     )
