@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -463,6 +463,8 @@ let rec pdecl fmt d =
           print_pair ptype (print_list semi string) in
         fprintf fmt "# Gen_Separation %s %s(%a)\n" kind s 
           (print_list comma print_ptype_r) l
+    | JCDpragma_gen_frame (name,logic) ->
+      fprintf fmt "# Gen_Frame %s %s" name logic
     | JCDaxiomatic(id,l) ->
 	fprintf fmt "@\n@[axiomatic %s {@\n@[<v 2>%a@]@\n}@]@\n" id
 	  (print_list space pdecl) l
