@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -61,6 +61,7 @@ type term =
   | LVarAtLabel of string * string     (*r x@L *)
   | Tnamed of string * term
   | TIf of term * term * term
+  | TLet of string * term * term
 
 let rec iter_term f t =
   match t with
@@ -71,7 +72,15 @@ let rec iter_term f t =
   | Tnamed(_,t) -> iter_term f t
   | TIf(t1,t2,t3) -> 
       iter_term f t1; iter_term f t2; iter_term f t3
+  | TLet(id,t1,t2) -> 
+      f id; iter_term f t1; iter_term f t2
 
+let rec match_term acc t1 t2 =
+  match t1, t2 with
+    | LVar id, _ -> (id,t2)::acc
+    | LApp(id1,l1), LApp(id2,l2) when id1 = id2 -> 
+      List.fold_left2 match_term acc l1 l2
+    | _ -> invalid_arg "match_term : t1 is not a valid context"
 
 let rec fprintf_term form t =
   match t with
@@ -91,10 +100,14 @@ let rec fprintf_term form t =
   | LApp(id,[])
   | LVar(id) -> fprintf form "%s" id
   | LVarAtLabel(id,l) -> fprintf form "%s@@%s" id l
-  | Tnamed(lab,t) -> fprintf form "(%s : %a)" lab fprintf_term t
+  | Tnamed(lab,t) -> 
+      fprintf form "(%s : %a)" lab fprintf_term t
   | TIf(t1,t2,t3) -> 
       fprintf form "@[<hov 1>(if %a@ then %a@ else %a)@]" 
 	fprintf_term t1 fprintf_term t2 fprintf_term t3
+  | TLet(v,t1,t2) -> 
+      fprintf form "@[<hov 1>(let %s@ = %a@ in %a)@]" v
+	fprintf_term t1 fprintf_term t2 
 
 type logic_type = 
     { logic_type_name : string;
@@ -143,6 +156,12 @@ let is_not_true a =
 
 let make_var s = LVar s
 
+let make_not a1 =
+  match unname a1 with
+    | LTrue -> LFalse
+    | LFalse -> LTrue
+    | _ -> LNot a1
+
 let make_or a1 a2 =
   match (unname a1,unname a2) with
     | (LTrue,_) -> LTrue
@@ -183,10 +202,16 @@ let make_impl a1 a2 =
     | (_,LFalse) -> LNot(a1)
     | (_,_) -> LImpl(a1,a2)
 
+let rec make_impl_list conclu = function
+  | [] -> conclu
+  | a::l -> LImpl(a,make_impl_list conclu l)
+
 let make_equiv a1 a2 =
   match (unname a1,unname a2) with
     | (LTrue,_) -> a2
     | (_,LTrue) -> a1
+    | (LFalse,_) -> make_not a2
+    | (_,LFalse) -> make_not a1
     | (_,_) -> LIff(a1,a2)
 
 let rec iter_assertion f a =
@@ -284,7 +309,7 @@ let rec fprintf_assertion form a =
   | LPred (id, []) -> 
       fprintf form "%s" id
   | LNamed (n, a) ->
-      fprintf form "@[(%s:@ %a)@]" n fprintf_assertion a
+      fprintf form "@[(%s:@ %a)@]" n fprintf_assertion a 
 
 and fprintf_triggers fmt trigs = 
   let pat fmt = function
@@ -400,7 +425,7 @@ type opaque = bool
 
 type assert_kind = [`ASSERT | `CHECK]
 
-type expr =
+type expr_node =
   | Cte of constant
   | Var of string
   | And of expr * expr
@@ -416,6 +441,9 @@ type expr =
       * expr list (* loop body *)
   | Block of expr list
   | Assign of string * expr
+  | MultiAssign of string * Loc.position * (string * expr) list * 
+      bool * term * expr * string * expr * string * 
+      (int * bool * bool * string) list
   | Let of string * expr * expr
   | Let_ref of string * expr * expr
   | App of expr * expr
@@ -426,68 +454,25 @@ type expr =
   | Triple of opaque * 
       assertion * expr * assertion * ((string * assertion) list)
   | Assert of assert_kind * assertion * expr
+(*
   | Label of string * expr
+*)
   | BlackBox of why_type
   | Absurd
   | Loc of Lexing.position * expr
+
+and expr = 
+    { expr_labels : string list;
+      expr_node : expr_node;
+    }
 ;;
 
-let make_or_expr a1 a2 =
-  match (a1,a2) with
-    | (Cte (Prim_bool true),_) -> Cte (Prim_bool true)
-    | (_,Cte (Prim_bool true)) -> Cte (Prim_bool true)
-    | (Cte (Prim_bool false),_) -> a2
-    | (_,Cte (Prim_bool false)) -> a1
-    | (_,_) -> Or(a1,a2)
-
-let make_and_expr a1 a2 =
-  match (a1,a2) with
-    | (Cte (Prim_bool true),_) -> a2
-    | (_,Cte (Prim_bool true)) -> a1
-    | (Cte (Prim_bool false),_) -> Cte (Prim_bool false)
-    | (_,Cte (Prim_bool false)) ->Cte (Prim_bool false)
-    | (_,_) -> And(a1,a2)
-
-
-let make_app_rec ~logic f l = 
-  let rec make_rec accu = function
-    | [] -> accu
-    | e::r -> make_rec (App(accu,e)) r
-  in
-  match l with
-    | [] -> if logic then make_rec f [] else make_rec f [Void]
-    | l -> make_rec f l
-;;
-
-let make_app id l = make_app_rec ~logic:false (Var id) l
-
-let make_logic_app id l = make_app_rec ~logic:true (Var id) l
-
-let make_app_e = make_app_rec ~logic:false
-
-let make_while cond inv var e =
-  let body = 
-    match e with
-      | Block(l) -> l
-      | _ -> [e]
-  in While(cond,inv,var,body)
-
-let make_label label e = Label (label, e)
-
-let make_pre pre e =  Triple(false,pre,e,LTrue,[])
-
-let append e1 e2 =
-  match e1,e2 with
-    | Void,_ -> e2
-    | _,Void -> e1
-    | Block(l1),Block(l2) -> Block(l1@l2)
-    | Block(l1),_ -> Block(l1@[e2])
-    | _,Block(l2) -> Block(e1::l2)
-    | _ -> Block [e1;e2]
-;;
+let mk_expr e = { expr_labels = []; expr_node = e }
+let mk_var s = mk_expr (Var s)
+let void = mk_expr Void
 
 let rec iter_expr f e =
-  match e with
+  match e.expr_node with
     | Cte(_c) -> ()
     | Var(id) -> f id
     | And(e1,e2) -> iter_expr f e1; iter_expr f e2
@@ -508,6 +493,9 @@ let rec iter_expr f e =
 	List.iter (iter_expr f) e2
     | Block(el) -> List.iter (iter_expr f) el
     | Assign(id,e) -> f id; iter_expr f e
+    | MultiAssign _ -> 
+        eprintf "Fatal error: Output.iter_expr called on MultiAssign@.";
+        assert false 
     | Let(_id,e1,e2) -> iter_expr f e1; iter_expr f e2
     | Let_ref(_id,e1,e2) -> iter_expr f e1; iter_expr f e2
     | App(e1,e2) -> iter_expr f e1; iter_expr f e2
@@ -525,7 +513,10 @@ let rec iter_expr f e =
 	iter_assertion f post;
 	List.iter (fun (_,a) -> iter_assertion f a) exceps
     | Assert(_,p, e) -> iter_assertion f p; iter_expr f e
-    | Label (_,e) | Loc (_,e) -> iter_expr f e
+(*
+    | Label (_,e) 
+*)
+    | Loc (_,e) -> iter_expr f e
     | BlackBox(ty) -> iter_why_type f ty
     | Absurd -> ()
 
@@ -535,7 +526,7 @@ let fprintf_variant form = function
   | Some (t, None) -> fprintf form "variant %a" fprintf_term t
   | Some (t, Some r) -> fprintf form "variant %a for %s" fprintf_term t r
 	  
-let rec fprintf_expr form e =
+let rec fprintf_expr_node form e =
   match e with
     | Cte(c) -> fprintf_constant form c
     | Var(id) -> fprintf form "%s" id
@@ -568,6 +559,8 @@ let rec fprintf_expr form e =
     | Assign(id,e) ->
 	fprintf form "@[<hov 1>(%s := %a)@]" 
 	  id fprintf_expr e
+    | MultiAssign _ -> 
+	fprintf form "@[<hov 1>(MultiAssign ...)@]" 
     | Let(id,e1,e2) ->
 	fprintf form "@[<hov 0>(let %s =@ %a in@ %a)@]" id
 	  fprintf_expr e1 fprintf_expr e2
@@ -639,8 +632,10 @@ let rec fprintf_expr form e =
 	fprintf form "@[<hov 0>(%s@ { %a };@ %a)@]" 
           (match k with `ASSERT -> "assert" | `CHECK -> "check")
 	  fprintf_assertion p fprintf_expr e
+(*
     | Label (s, e) ->
 	fprintf form "@[<hov 0>(%s:@ %a)@]" s fprintf_expr e
+*)
     | BlackBox(t) ->
 	fprintf form "@[<hov 0>[ %a ]@]" 
 	  (fprintf_type false) t
@@ -653,6 +648,19 @@ let rec fprintf_expr form e =
 	  (l.pos_cnum - l.pos_bol) fprintf_expr e
 	*)
 
+and fprintf_expr form e =
+  let rec aux l =
+    match l with 
+      | [] -> fprintf_expr_node form e.expr_node
+      | s::l ->
+(*
+          if s="L2" then Format.eprintf "Output.fprintf_expr: printing label %s for expression %a@." s fprintf_expr_node e.expr_node;
+*)
+          fprintf form "@[<hov 0>(%s:@ " s;
+          aux l;
+          fprintf form ")@]"
+  in aux e.expr_labels 
+
 and fprintf_expr_list form l =
   match l with
     | [] -> ()
@@ -668,6 +676,143 @@ and fprintf_expr_end_list form l =
 	fprintf_expr_end_list form l
 ;;
 
+let make_or_expr a1 a2 =
+  match (a1.expr_node,a2.expr_node) with
+    | (Cte (Prim_bool true),_) -> a1
+    | (_,Cte (Prim_bool true)) -> a2
+    | (Cte (Prim_bool false),_) -> a2
+    | (_,Cte (Prim_bool false)) -> a1
+    | (_,_) -> mk_expr (Or(a1,a2))
+
+let make_and_expr a1 a2 =
+  match (a1.expr_node,a2.expr_node) with
+    | (Cte (Prim_bool true),_) -> a2
+    | (_,Cte (Prim_bool true)) -> a1
+    | (Cte (Prim_bool false),_) -> a1
+    | (_,Cte (Prim_bool false)) -> a2
+    | (_,_) -> mk_expr (And(a1,a2))
+
+
+let make_app_rec ~logic f l = 
+  let rec make_rec accu = function
+    | [] -> accu
+    | e::r -> make_rec (mk_expr (App(accu,e))) r
+  in
+  match l with
+    | [] -> if logic then make_rec f [] else make_rec f [void]
+    | l -> make_rec f l
+;;
+
+let make_app id l = make_app_rec ~logic:false (mk_var id) l
+
+let make_logic_app id l = make_app_rec ~logic:true (mk_var id) l
+
+let make_app_e = make_app_rec ~logic:false
+
+let make_while cond inv var e =
+  let body = 
+    match e.expr_node with
+      | Block(l) -> l
+      | _ -> [e]
+  in mk_expr (While(cond,inv,var,body))
+
+let make_label label e = 
+(*
+  if label = "L2" then Format.eprintf "Output.make_label: adding label %s@." label;
+*)
+  { e with expr_labels = label :: e.expr_labels }
+
+let make_pre pre e =  mk_expr (Triple(false,pre,e,LTrue,[]))
+
+
+
+
+let compare_parallel_assign (i,_,_,_) (j,_,_,_) =
+  let c = Pervasives.compare i j in
+  if c = 0 then raise Exit else c
+
+
+let append_list e l =
+(*
+  Format.eprintf "Entering append_list@.";
+*)
+  match l with
+    | [] -> [e]
+    | e'::rem ->
+        match e.expr_node,e'.expr_node with
+          | MultiAssign(mark1,pos1,lets1,isrefa1,ta1,a1,tmpe1,e1,f1,l1), 
+            MultiAssign(_,_,lets2,_isrefa2,_ta2,a2,_tmpe2,e2,f2,l2) ->
+              (*
+                Format.eprintf 
+                "Found multi-assigns: a1=%a, a2=%a, e1=%a, e2=%a, f1=%s,f2=%s@."
+                fprintf_expr a1 fprintf_expr a2 
+                fprintf_expr e1 fprintf_expr e2 f1 f2;
+              *)
+              if a1 = a2 && e1 = e2 && f1 = f2 then
+                begin
+                  try
+                    let l = List.merge compare_parallel_assign l1 l2 in
+                    (*
+                      Format.eprintf "append_list, merge successful!@.";             
+                    *)
+                    { expr_labels = e.expr_labels @ e'.expr_labels ;
+                      expr_node = 
+                        MultiAssign(mark1,pos1,lets1@lets2,isrefa1,ta1,a1,tmpe1,e1,f1,l) }
+                    ::rem
+                  with Exit ->
+                    (*
+                      Format.eprintf "append_list, merge failed...@.";             
+                    *)
+                    e::l
+                end
+              else
+                begin
+                  (*
+                    Format.eprintf "do not match@.";
+                  *)
+                  e::l
+                end
+          | MultiAssign _, _e' ->
+              (*
+                Format.eprintf "MultiAssign not followed by MultiAssign but by %a@."
+                fprintf_expr e';
+              *)
+              e::l
+          | _, MultiAssign _ ->
+              (*
+                Format.eprintf "MultiAssign not preceeded by MultiAssign@.";
+              *)
+              e::l
+          | _ -> 
+              (*
+                Format.eprintf "no MultiAssign at all@.";
+              *)
+              e::l
+        
+
+let make_block labels l =
+  match l with
+      | [] -> assert false
+      | [e] -> {e with expr_labels = labels @ e.expr_labels }
+      | _ -> { expr_labels = labels ; expr_node = Block l }
+ 
+
+let append e1 e2 =
+  match e1.expr_node,e2.expr_node with
+    | Void,_ -> assert (e1.expr_labels = []); e2
+    | _,Void -> assert (e2.expr_labels = []); e1
+    | Block(l1),Block(l2) -> 
+        make_block (e1.expr_labels@e2.expr_labels) 
+          (List.fold_right append_list l1 l2)
+    | Block(l1),_ -> 
+        make_block e1.expr_labels (List.fold_right append_list l1 [e2])
+    | _,Block(l2) -> 
+        make_block e2 .expr_labels (append_list e1 l2)
+    | _ -> make_block [] (append_list e1 [e2])
+
+
+type goal_kind = KAxiom | KLemma | KGoal
+
 type why_decl =
   | Param of bool * string * why_type         (*r parameter in why *)
   | Def of string * expr               (*r global let in why *)
@@ -675,8 +820,7 @@ type why_decl =
   | Predicate of bool * string * (string * logic_type) list * assertion  
   | Inductive of bool * string * (string * logic_type) list *  
       (string * assertion) list (*r inductive definition *)
-  | Axiom of string * assertion         (*r Axiom *)
-  | Goal of string * assertion         (*r Goal *)
+  | Goal of goal_kind * string * assertion         (*r Goal *)
   | Function of bool * string * (string * logic_type) list * logic_type * term
   | Type of string * string list
   | Exception of string * logic_type option
@@ -688,8 +832,7 @@ let get_why_id d =
     | Param(_,id,_) 
     | Logic(_,id,_,_)
     | Def(id,_) 
-    | Axiom(id,_) 
-    | Goal(id,_) 
+    | Goal(_,id,_) 
     | Predicate(_,id,_,_) 
     | Function(_,id,_,_,_) 
     | Inductive(_,id,_,_)
@@ -709,7 +852,7 @@ let iter_why_decl f d =
     | Predicate(_,_id,args,p) -> 
 	List.iter (fun (_,t) -> iter_logic_type f t) args;
 	iter_assertion f p
-    | Goal(_id,t) | Axiom(_id,t) -> iter_assertion f t
+    | Goal(_,_id,t) -> iter_assertion f t
     | Function(_,_id,args,t,p) -> 
 	List.iter (fun (_,t) -> iter_logic_type f t) args;
 	iter_logic_type f t;
@@ -761,6 +904,11 @@ let build_map get_id decl_list =
 let fprint_logic_arg form (id,t) =
   fprintf form "%s:%a" id fprintf_logic_type t
 
+let str_of_goal_kind = function
+  | KAxiom -> "axiom"
+  | KLemma -> "lemma"
+  | KGoal -> "goal"
+
 let fprintf_why_decl form d =
   match d with
     | Param(b,id,t) ->
@@ -780,11 +928,8 @@ let fprintf_why_decl form d =
 	     (fun _fmt (id,a) ->
 		fprintf form "| %s: @[%a@]" id fprintf_assertion a))
 	  cases
-    | Axiom(id,p) ->
-	fprintf form "@[<hov 1>axiom %s :@ %a@]@.@." id 
-	  fprintf_assertion p
-    | Goal(id,p) ->
-	fprintf form "@[<hov 1>goal %s :@ %a@]@.@." id 
+    | Goal(k,id,p) ->
+	fprintf form "@[<hov 1>%s %s :@ %a@]@.@." (str_of_goal_kind k) id 
 	  fprintf_assertion p
     | Def(id,e) ->
 	fprintf form "@[<hov 1>let %s =@ %a@]@.@." id fprintf_expr e
@@ -872,10 +1017,10 @@ let fprintf_why_decls form decls =
 	   | _ -> (t, p, d, decl::o))
       ([], [], [], []) decls
   in
-    output_decls get_why_id iter_why_decl (fprintf_why_decl form) types;
-    output_decls get_why_id iter_why_decl (fprintf_why_decl form) others;
-    output_decls get_why_id iter_why_decl (fprintf_why_decl form) params;
-    output_decls get_why_id iter_why_decl (fprintf_why_decl form) defs
+  output_decls get_why_id iter_why_decl (fprintf_why_decl form) types;
+  output_decls get_why_id iter_why_decl (fprintf_why_decl form) others;
+  output_decls get_why_id iter_why_decl (fprintf_why_decl form) params;
+  output_decls get_why_id iter_why_decl (fprintf_why_decl form) defs
 
 
 (*s locs table *)
@@ -939,7 +1084,8 @@ let print_pos fmt =
 	 (fun n -> fprintf fmt "name = \"%s\"@\n" n) name;
        Option_misc.iter
 	 (fun n -> fprintf fmt "formula = \"%s\"@\n" n) formula;
-       fprintf fmt "file = \"%s\"@\n" (String.escaped (abs_fname b.Lexing.pos_fname));
+       fprintf fmt "file = \"%s\"@\n" 
+         (String.escaped (abs_fname b.Lexing.pos_fname));
        let l = b.Lexing.pos_lnum in
        let fc = b.Lexing.pos_cnum - b.Lexing.pos_bol in
        let lc = e.Lexing.pos_cnum - b.Lexing.pos_bol in
