@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -57,6 +57,9 @@ type term =
   | LVarAtLabel of string * string     (*r x@L *)
   | Tnamed of string * term
   | TIf of term * term * term
+  | TLet of string * term * term
+
+val match_term : (string * term) list -> term -> term -> (string * term) list
 
 val fprintf_term : Format.formatter -> term -> unit
 
@@ -90,6 +93,7 @@ val make_and_list : assertion list -> assertion
 val make_forall_list : (string * logic_type) list -> trigger list list 
   -> assertion -> assertion
 val make_impl : assertion -> assertion -> assertion
+val make_impl_list : assertion -> assertion list -> assertion
 val make_equiv : assertion -> assertion -> assertion
 
 val fprintf_assertion : Format.formatter -> assertion -> unit
@@ -115,7 +119,7 @@ type opaque = bool
 
 type assert_kind = [`ASSERT | `CHECK]
 
-type expr =
+type expr_node =
   | Cte of constant
   | Var of string
   | And of expr * expr
@@ -131,6 +135,24 @@ type expr =
       * expr list (* loop body *)
   | Block of expr list
   | Assign of string * expr
+  | MultiAssign of string * Loc.position * (string * expr) list * 
+      bool * term * expr * string * expr * string *  
+      (int * bool * bool * string) list
+      (* 
+
+         this construction is not in Why, but a temporary construction
+         used by jessie to denote "parallel updates"
+         
+         [MultiAssign(mark,pos,lets,talloc,alloc,tmpe,e,f,l)] where [l]
+         is a list of pair (i,b1,b2,e') for distincts i, denotes the
+         parallel updates (lets) let tmpe = e in (tmpe+i).f = e'
+
+         booleans [b1] and [b2] indicates whether it is safe to ignore
+         bound checking on the left resp on the right
+         
+         [alloc] is the allocation table for safety conditions
+         [lets] is a sequence of local bindings for expressions e'
+      *)
   | Let of string * expr * expr
   | Let_ref of string * expr * expr
   | App of expr * expr
@@ -141,12 +163,26 @@ type expr =
   | Triple of opaque * 
       assertion * expr * assertion * ((string * assertion) list)
   | Assert of assert_kind * assertion * expr
+(*
   | Label of string * expr
+*)
   | BlackBox of why_type
   | Absurd 
   | Loc of Lexing.position * expr
+
+and expr = 
+    { expr_labels : string list;
+      expr_node : expr_node;
+    }
+
 ;;
 
+val mk_expr : expr_node -> expr
+val mk_var : string -> expr
+val void : expr
+
+val make_block : string list -> expr list -> expr
+
 val fprintf_expr : Format.formatter -> expr -> unit
 
 val make_or_expr : expr -> expr -> expr
@@ -166,13 +202,8 @@ val make_app_e : expr -> expr list -> expr
 
 (*
 
-  [make_label l e] builds
+  [make_label l e] adds label l to e
 
-    begin label l; e end
-
-  applying simplification if [e] is already a block
-
-    
 
 *)
 
@@ -193,6 +224,7 @@ val make_pre : assertion -> expr -> expr;;
 
 val append : expr -> expr -> expr
 
+type goal_kind = KAxiom | KLemma | KGoal
 type why_decl =
   | Param of bool * string * why_type         (*r parameter in why *)
   | Def of string * expr               (*r global let in why *)
@@ -200,8 +232,7 @@ type why_decl =
   | Predicate of bool * string * (string * logic_type) list * assertion  
   | Inductive of bool * string * (string * logic_type) list *  
       (string * assertion) list (*r inductive definition *)
-  | Axiom of string * assertion         (*r Axiom *)
-  | Goal of string * assertion         (*r Goal *)
+  | Goal of goal_kind * string * assertion         (*r Goal *)
   | Function of bool * string * (string * logic_type) list * logic_type * term
   | Type of string * string list
   | Exception of string * logic_type option
