@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -100,8 +100,10 @@ let prefix_id id =
   else if id == t_add_int then "Zplus"
   else if id == t_sub_int then "Zminus"
   else if id == t_mul_int then "Zmult"
+(*
   else if id == t_div_int then "Zdiv"
   else if id == t_mod_int then "Zmod"
+*)
   else if id == t_neg_int then "Zopp"
   (* real ops *)
   else if id == t_add_real then "Rplus"
@@ -166,10 +168,12 @@ let print_term_v7 fmt t =
   and print2 fmt = function
     | Tapp (id, [a;b], _) when id == t_mul_int ->
 	openz fmt; fprintf fmt "%a *@ %a" print2 a print3 b; closez fmt
+(*
     | Tapp (id, [a;b], _) when id == t_div_int ->
 	fprintf fmt "(@[Zdiv %a@ %a@])" print3 a print3 b
     | Tapp (id, [a;b], _) when id == t_mod_int ->
 	fprintf fmt "(@[Zmod %a@ %a@])" print3 a print3 b
+*)
     | t ->
 	print3 fmt t
   and print3 fmt = function
@@ -197,7 +201,11 @@ let print_term_v7 fmt t =
     | Tapp (id, [_;_], _) as t when is_relation id || is_int_arith_binop id ->
 	fprintf fmt "@[(%a)@]" print0 t
     | Tapp (id, [a; b; c], _) when id == if_then_else ->
-	fprintf fmt "(@[if_then_else %a@ %a@ %a@])" print0 a print0 b print0 c
+	(* was print0 instead of print3, was wrong because printed
+	     if_then_else (x < y) y-x x-y
+	   missing parentheses
+	*)
+	fprintf fmt "(@[if_then_else %a@ %a@ %a@])" print3 a print3 b print3 c
     | Tapp (id, tl, _) when id == t_zwf_zero ->
 	fprintf fmt "(@[Zwf 0 %a@])" print_terms tl
     | Tapp (id, tl, _) when is_relation id || is_arith id ->
@@ -459,10 +467,12 @@ let print_term_v8 fmt t =
   and print2 fmt = function
     | Tapp (id, [a;b], _) when id == t_mul_int ->
 	fprintf fmt "%a *@ %a" print2 a print3 b
+(*
     | Tapp (id, [a;b], _) when id == t_div_int ->
 	fprintf fmt "(@[Zdiv %a@ %a@])" print3 a print3 b
     | Tapp (id, [a;b], _) when id == t_mod_int ->
 	fprintf fmt "(@[Zmod %a@ %a@])" print3 a print3 b
+*)
     | t ->
 	print3 fmt t
   and print3 fmt = function
@@ -804,18 +814,21 @@ let print_sequent fmt s =
 
 (*let _ = Vcg.log_print_function := print_sequent*)
 
-let reprint_obligation fmt loc _expl id s =
+let reprint_obligation fmt loc _is_lemma _expl id s =
   fprintf fmt "@[(* %a *)@]@\n" (Loc.report_obligation_position  ~onlybasename:true) loc;
   fprintf fmt "@[<hov 2>(*Why goal*) Lemma %s : @\n%a.@]@\n" id print_sequent s
   (*;
   fprintf fmt "@[<hov 2>(* %a *)@]@\n" Util.print_explanation expl
   *)
+ 
 
-let print_obligation fmt loc expl id s =
-  reprint_obligation fmt loc expl id s;
+let print_obligation fmt loc is_lemma expl id s =
+  reprint_obligation fmt loc is_lemma expl id s;
   fprintf fmt "Proof.@\n";
   option_iter (fun t -> fprintf fmt "%s.@\n" t) coq_tactic;
-  fprintf fmt "(* FILL PROOF HERE *)@\nSave.@\n"
+  fprintf fmt "(* FILL PROOF HERE *)@\nSave.@\n";
+  if is_lemma && v81 && coq_use_dp then 
+    fprintf fmt "@[<hov 2>Dp_hint %s.@]@\n" id
 
 let reprint_parameter fmt id c =
   let (l,c) = Env.specialize_cc_type c in
@@ -881,7 +894,8 @@ let reprint_axiom fmt id p =
 let print_axiom fmt id p =
   reprint_axiom fmt id p;
   fprintf fmt "Admitted.@\n";
-  if v81 then fprintf fmt "@[<hov 2>Dp_hint %a.@]@\n" idents id;
+  if v81 && coq_use_dp then 
+    fprintf fmt "@[<hov 2>Dp_hint %a.@]@\n" idents id;
   if not !is_last_file then add_library_hints id
   (* if is_polymorphic p then fprintf fmt "Implicit Arguments %s.@\n" id *)
 
@@ -1046,7 +1060,8 @@ struct
     begin match e with
       | Parameter (id, c) -> print_parameter fmt id c
       | Program (id, tt, v) -> print_cc_functional_program fmt (id, tt, v)
-      | Obligation (loc, expl, id, s) -> print_obligation fmt loc expl id s
+      | Obligation (loc, is_lemma, expl, id, s) -> 
+	  print_obligation fmt loc is_lemma expl id s
       | Logic (id, t) -> print_logic fmt id t
       | Axiom (id, p) -> print_axiom fmt id p
       | Predicate (id, p) -> print_predicate_def fmt id p
@@ -1060,7 +1075,8 @@ struct
   let reprint_element fmt = function
     | Parameter (id, c) -> reprint_parameter fmt id c
     | Program (id, tt, v) -> print_cc_functional_program fmt (id, tt, v)
-    | Obligation (loc, expl, id, s) -> reprint_obligation fmt loc expl id s
+    | Obligation (loc, is_lemma, expl, id, s) -> 
+	reprint_obligation fmt loc is_lemma expl id s
     | Logic (id, t) -> reprint_logic fmt id t
     | Axiom (id, p) -> reprint_axiom fmt id p
     | Predicate (id, p) -> reprint_predicate_def fmt id p
@@ -1091,8 +1107,8 @@ end)
 let reset = Gen.reset
 
 let push_decl = function
-  | Dgoal (loc,expl,l,s) ->
-      Gen.add_elem (Oblig, l) (Obligation (loc,expl,l,s))
+  | Dgoal (loc,is_lemma,expl,l,s) ->
+      Gen.add_elem (Oblig, l) (Obligation (loc,is_lemma,expl,l,s))
   | Dlogic (_, id, t) ->
       let id = Ident.string id in
       Gen.add_elem (Lg, rename id) (Logic (id, t))
