@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -63,7 +63,9 @@ let infix id =
   else if id == t_add_int then "+"
   else if id == t_sub_int then "-"
   else if id == t_mul_int then "*"
+(*
   else if id == t_div_int then "/"
+*)
   (* real ops *)
   else if id == t_add_real then "+"
   else if id == t_sub_real then "-"
@@ -108,8 +110,10 @@ let rec print_term fmt = function
 	"(%s / %s)" fmt c
   | Tderef _ -> 
       assert false
+(*
   | Tapp (id, ([_;_] as tl), _) when id == t_mod_int ->
       fprintf fmt "@[%a(%a)@]" Ident.print id print_terms tl
+*)
   | Tapp (id, [a], _) when id == t_sqrt_real || id == t_int_of_real ->
       fprintf fmt "@[%a(%a)@]" Ident.print id print_term a
   | Tapp (id, [a], _) when id == t_real_of_int ->
@@ -280,12 +284,16 @@ let print_axiom fmt id p =
   fprintf fmt "@[%%%% Why axiom %s@]@\n" id;
   fprintf fmt "@[<hov 2>ASSERT %a;@]@\n@\n" print_predicate p
 
-let print_obligation fmt loc _expl o s = 
+let print_obligation fmt loc is_lemma _expl o s = 
   fprintf fmt "@[%%%% %s, %a@]@\n" o Loc.gen_report_line loc;
-  fprintf fmt "PUSH;@\n@[<hov 2>QUERY %a;@]@\nPOP;@\n@\n" print_sequent s
+  fprintf fmt "PUSH;@\n@[<hov 2>QUERY %a;@]@\nPOP;@\n@\n" print_sequent s;
 (*;
-  fprintf fmt "@[%%%% %a@]@\n" Util.print_explanation expl
+  fprintf fmt "@[%%%% %a@]@\n" Util.print_explanation expl;
 *)
+  if is_lemma then begin
+    fprintf fmt "@[%%%%  %s as axiom@]@\n" o;
+    fprintf fmt "@[<hov 2>ASSERT %a;@]@\n@\n" print_sequent s;
+  end
 
 let push_decl d = Encoding.push ~encode_preds:false ~encode_funs:false d
 
@@ -316,8 +324,8 @@ let output_elem fmt = function
       print_function_def fmt id d.scheme_type
   | Daxiom (_loc, id, p) ->
       print_axiom fmt id p.scheme_type
-  | Dgoal (loc, expl, id, s) ->
-      print_obligation fmt loc expl id s.Env.scheme_type
+  | Dgoal (loc, is_lemma, expl, id, s) ->
+      print_obligation fmt loc is_lemma expl id s.Env.scheme_type
 
 let prelude_done = ref false
 let prelude fmt = 
