@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 open Cc
 open Logic
@@ -727,9 +727,9 @@ let rec translate_assertion env iter_fun d =
 				      (lifted_t argl (Piff (rootexp, pred)) [[PPat rootexp]])))) in
       env*)
 (* A function definition can be handled as a function logic definition + an axiom *)
-  | Dinductive_def(_loc, _ident, _inddef) ->
-      failwith "encoding mono: inductive def not yet supported"
-  | Dfunction_def _(*loc, ident, fun_def_sch*) ->
+  | Dinductive_def(_,id,d) ->
+      List.fold_left ta env (PredDefExpansor.inductive_def loc id d)
+  | Dfunction_def (loc, id, d) ->
 (*       let _ = print_endline ident in *)
 (*      let (argl, rt, term) = fun_def_sch.Env.scheme_type in
       let rootexp = (Tapp (ident, List.map (fun (i,_) -> Tvar i) argl, [])) in
@@ -738,7 +738,7 @@ let rec translate_assertion env iter_fun d =
 		    (Env.generalize_predicate
 		       (lifted_t argl (Papp (Ident.t_eq, [rootexp; term], [])) [[TPat rootexp]])))) in
       env*)
-      assert false
+      List.fold_left ta env (PredDefExpansor.function_def loc id d)
 (* Axiom definitions *)
   | Daxiom (loc, ident, pred_sch) ->
       let insts,p_inst = E.give_inst env pred_sch in
@@ -754,7 +754,7 @@ let rec translate_assertion env iter_fun d =
                    iter_fun (Daxiom (loc, ident, new_axiom))) insts;
       env
 (* A goal is a sequent : a context and a predicate and both have to be translated *)
-  | Dgoal (loc, expl, ident, s_sch) ->
+  | Dgoal (loc, is_lemma, expl, ident, s_sch) ->
       begin try
 	let new_cel =
 	  List.map
@@ -770,10 +770,10 @@ let rec translate_assertion env iter_fun d =
 	  Env.empty_scheme
 	    (new_cel,
 	     translate_pred env Env.Vmap.empty (snd (s_sch.Env.scheme_type))) in
-	iter_fun (Dgoal (loc, expl, ident, new_sequent))
+	iter_fun (Dgoal (loc, is_lemma, expl, ident, new_sequent))
       with Not_found -> 
 	Format.eprintf "Exception caught in : %a\n" Util.print_decl d;
-	iter_fun (Dgoal (loc, expl, ident, Env.empty_scheme([],Pfalse)));
+	iter_fun (Dgoal (loc, is_lemma, expl, ident, Env.empty_scheme([],Pfalse)));
       end;env)
   with Not_found -> 
     Format.eprintf "Exception caught in : %a\n" Util.print_decl d;
@@ -863,7 +863,7 @@ let make_world_sorted ~monotype ~monosig ~monodef world  = function
       else world
   | Daxiom(_,_,sch) when Env.Vset.is_empty sch.Env.scheme_vars ->
       make_world_predicate world sch.Env.scheme_type
-  | Dgoal (_,_,_,{Env.scheme_vars =v;scheme_type=(con,p)}) 
+  | Dgoal (_,_,_,_,{Env.scheme_vars =v;scheme_type=(con,p)}) 
       when Env.Vset.is_empty v ->
       let world = make_world_predicate world p in
       List.fold_left make_world_context_element world con
@@ -871,7 +871,7 @@ let make_world_sorted ~monotype ~monosig ~monodef world  = function
   | _ -> world (* Polymorph case *)
 
 let make_world_just_goal world  = function
-  | Dgoal (_,_,_,{Env.scheme_vars =v;scheme_type=(con,p)}) 
+  | Dgoal (_,_,_,_,{Env.scheme_vars =v;scheme_type=(con,p)}) 
       when Env.Vset.is_empty v ->
       let world = make_world_predicate world p in
       List.fold_left make_world_context_element world con
@@ -887,7 +887,7 @@ let make_world = match Options.monoinstworldgen with
   | Options.MonoinstPremises -> make_world_sorted ~monotype:false  ~monodef:true ~monosig:false
 
 let monomorph_goal acc = function
-  | Dgoal (loc,vc,id,sch) ->
+  | Dgoal (loc,is_lemma,vc,id,sch) ->
       let cpt = ref 0 in
       let fv = Env.Vset.fold
 	(fun _ acc -> 
@@ -899,7 +899,7 @@ let monomorph_goal acc = function
                              PTexternal ([],x)) fv in
       let p = Env.instantiate_sequent sch inst in
       let acc = List.fold_left (fun acc x -> Dtype (loc,x,[])::acc) acc fv in
-      Dgoal (loc,vc,id,Env.empty_scheme p)::acc
+      Dgoal (loc,is_lemma,vc,id,Env.empty_scheme p)::acc
   | x -> x::acc
 
 let push_decl a = Queue.add a queue
