@@ -1,22 +1,26 @@
 (**************************************************************************)
 (*                                                                        *)
 (*  The Why platform for program certification                            *)
-(*  Copyright (C) 2002-2008                                               *)
-(*    Romain BARDOU                                                       *)
-(*    Jean-Franois COUCHOT                                               *)
-(*    Mehdi DOGGUY                                                        *)
-(*    Jean-Christophe FILLITRE                                           *)
-(*    Thierry HUBERT                                                      *)
-(*    Claude MARCH                                                       *)
-(*    Yannick MOY                                                         *)
-(*    Christine PAULIN                                                    *)
-(*    Yann RGIS-GIANAS                                                   *)
-(*    Nicolas ROUSSET                                                     *)
-(*    Xavier URBAIN                                                       *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
 (*                                                                        *)
 (*  This software is free software; you can redistribute it and/or        *)
-(*  modify it under the terms of the GNU Library General Public           *)
-(*  License version 2, with the special exception on linking              *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
 (*  described in file LICENSE.                                            *)
 (*                                                                        *)
 (*  This software is distributed in the hope that it will be useful,      *)
@@ -89,10 +93,12 @@ let arith_kernel =
 	   Env.empty_scheme (Function ([PTint; PTint], PTint))))::
   (Dlogic (loc, Ident.t_mul_int,
 	   Env.empty_scheme (Function ([PTint; PTint], PTint))))::
+(*
   (Dlogic (loc, Ident.t_div_int,
 	   Env.empty_scheme (Function ([PTint; PTint], PTint))))::
   (Dlogic (loc, Ident.t_mod_int,
 	   Env.empty_scheme (Function ([PTint; PTint], PTint))))::
+*)
   (Dlogic (loc, Ident.t_neg_int,
 	   Env.empty_scheme (Function ([PTint], PTint))))::
   (Dlogic (loc, Ident.t_lt_int,
@@ -378,7 +384,7 @@ let rec push d =
 	Env.empty_scheme (lifted fv (translate_pred fv [] pred_sch.Env.scheme_type) []) in
       Queue.add (Daxiom (loc, name, new_axiom)) queue
 (* A goal is a sequent : a context and a predicate and both have to be translated *)
-  | Dgoal (loc, expl, name, s_sch) ->
+  | Dgoal (loc, is_lemma, expl, name, s_sch) ->
       begin try
 	let cpt = ref 0 in
 	let fv = Env.Vset.fold
@@ -396,10 +402,10 @@ let rec push d =
 	  Env.empty_scheme
 	    (lifted_ctxt fv (List.rev new_cel),
 	     translate_eq (translate_pred fv context (snd (s_sch.Env.scheme_type)))) in
-	Queue.add (Dgoal (loc, expl, name, new_sequent)) queue
+	Queue.add (Dgoal (loc, is_lemma, expl, name, new_sequent)) queue
       with Not_found -> 
 	Format.eprintf "Exception Not_found caught in : %a\n" Util.print_decl d;
-	Queue.add (Dgoal (loc, expl, name, Env.empty_scheme([],Pfalse))) queue
+	Queue.add (Dgoal (loc, is_lemma, expl, name, Env.empty_scheme([],Pfalse))) queue
       end)
   with
     Not_found -> 
