@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -59,8 +59,8 @@ let push_decl = function
   | Dpredicate_def (_, id, p) -> Queue.add (Predicate (Ident.string id, p)) elem_q
   | Dinductive_def(_loc, _ident, _inddef) ->
       failwith "HOL light output: inductive def not yet supported"
-  | Dgoal (loc,expl,id,s) -> 
-      Queue.add (Obligation (loc,expl,id,s.Env.scheme_type)) elem_q
+  | Dgoal (loc,is_lemma,expl,id,s) -> 
+      Queue.add (Obligation (loc,is_lemma,expl,id,s.Env.scheme_type)) elem_q
   | Dfunction_def _ -> () (*TODO*)
   | Dtype _ -> () (*TODO*)
   | Dalgtype _ -> () (*TODO*)
@@ -104,8 +104,10 @@ let prefix_id id =
   else if id == t_add_int then "int_add"
   else if id == t_sub_int then "int_sub"
   else if id == t_mul_int then "int_mul"
+(*
   else if id == t_div_int then assert false (* TODO *)
   else if id == t_mod_int then assert false (* TODO *)
+*)
   else if id == t_neg_int then "int_neg"
   (* real ops *)
   else if id == t_add_real then "real_add"
@@ -256,14 +258,14 @@ let print_predicate fmt id p =
   fprintf fmt "@[<hov 2>let %s = new_definition@ `%s %a = %a`;;@\n@\n@]" 
     id id (print_list space Ident.print) (List.map fst bl) print_predicate p
 
-let print_obligation fmt _loc id sq =
+let print_obligation fmt _loc _is_lemma id sq =
 (*
   fprintf fmt "@[(* %a *)@]@\n" Loc.report_obligation_position loc;
 *)
   fprintf fmt "@[<hov 2>let %s =@ `%a`;;@\n@\n@]" id print_sequent sq
 
 let print_elem fmt = function
-  | Obligation (loc, _expl, s, sq) -> print_obligation fmt loc s sq
+  | Obligation (loc, is_lemma, _expl, s, sq) -> print_obligation fmt loc is_lemma s sq
   | Logic (id, t) -> print_logic fmt id t
   | Axiom (id, p) -> print_axiom fmt id p
   | Predicate (id, p) -> print_predicate fmt id p
@@ -271,7 +273,7 @@ let print_elem fmt = function
 let print_obl_list fmt = 
   let comma = ref false in
   let print = function
-    | Obligation (_,_,id,_) -> 
+    | Obligation (_,_,_,id,_) -> 
 	if !comma then fprintf fmt "; "; fprintf fmt "%s" id; comma := true
     | Axiom _ | Logic _ | Predicate _ -> 
 	()
