@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -152,8 +152,10 @@ let t_neg = create "%neg"
 let t_add_int = create "add_int"
 let t_sub_int = create "sub_int"
 let t_mul_int = create "mul_int"
+(*
 let t_div_int = create "div_int"
 let t_mod_int = create "mod_int"
+*)
 let t_neg_int = create "neg_int"
 let t_abs_int = create "abs_int"
 
@@ -166,6 +168,11 @@ let t_abs_real = create "abs_real"
 let t_pow_real = create "pow_real"
 let t_sqrt_real = create "sqrt_real"
 
+let t_cos = create "cos"
+let t_sin = create "sin"
+let t_tan = create "tan"
+let t_atan = create "atan"
+
 let t_int_max = create "int_max"
 let t_int_min = create "int_min"
 let t_real_max = create "real_max"
@@ -175,8 +182,10 @@ let t_real_of_int = create "real_of_int"
 let t_int_of_real = create "int_of_real"
 
 let t_div_real_ = create "div_real_"
+(*
 let t_div_int_ = create "div_int_"
 let t_mod_int_ = create "mod_int_"
+*)
 let t_sqrt_real_ = create "sqrt_real_"
 
 let t_distinct = create "distinct"
@@ -326,8 +335,10 @@ let is_relation_ id =
   is_bool_comparison_ id || is_unit_comparison_ id
 
 let is_int_arith_binop id =
-  id == t_add_int || id == t_sub_int || id == t_mul_int || id == t_div_int ||
-  id == t_mod_int
+  id == t_add_int || id == t_sub_int || id == t_mul_int 
+(* disabled (confusion math_div / computer_div
+  || id == t_div_int || id == t_mod_int
+*)
 
 let is_real_arith_binop id =
   id == t_add_real || id == t_sub_real || id == t_mul_real || 
