@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 (*s Isabelle/HOL output *)
 
@@ -137,8 +137,10 @@ let prefix_id id =
   else if id == t_add_int then "(op +)"
   else if id == t_sub_int then "(op -)"
   else if id == t_mul_int then "(op *)"
+(*
   else if id == t_div_int then "(op div)"
   else if id == t_mod_int then "(op mod)"
+*)
   else if id == t_neg_int then "(%x. - x)"
   (* real ops *)
   else if id == t_add_real then "(op +)"
@@ -179,10 +181,12 @@ let rec print_term fmt = function
       fprintf fmt "(@[%a *@ %a@])" print_term a print_term b
   | Tapp (id, [a; b], _) when id == t_div_real ->
       fprintf fmt "(@[%a /@ %a@])" print_term a print_term b
+(*
   | Tapp (id, [a; b], _) when id == t_mod_int ->
       fprintf fmt "(@[%a mod@ %a@])" print_term a print_term b
   | Tapp (id, [a; b], _) when id == t_div_int ->
       fprintf fmt "(@[%a div@ %a@])" print_term a print_term b
+*)
   | Tapp (id, [a], _) when id == t_neg_int || id == t_neg_real ->
       fprintf fmt "(@[-%a@])" print_term a
   | Tapp (id, [a; b; c], _) when id == if_then_else -> 
@@ -309,15 +313,15 @@ let reprint_axiom fmt id p =
 let print_axiom fmt id p = 
   reprint_axiom fmt id p
 
-let reprint_obligation fmt loc _expl id s =
+let reprint_obligation fmt loc _is_lemma _expl id s =
   fprintf fmt "@[(* %a *)@]@\n" (Loc.report_obligation_position ~onlybasename:true) loc;
   fprintf fmt "@[<hov 4>(*Why goal*) lemma %a:@\n%a;@]@\n" idents id print_sequent s
 (*;
   fprintf fmt "@[(* %a *)@]@\n" Util.print_explanation expl
 *)
 
-let print_obligation fmt loc expl id s = 
-  reprint_obligation fmt loc expl id s;
+let print_obligation fmt loc is_lemma expl id s = 
+  reprint_obligation fmt loc is_lemma expl id s;
   fprintf fmt "(* FILL PROOF HERE *)@\n@\n"
 
 let reprint_predicate fmt id p =
@@ -405,8 +409,8 @@ struct
     begin match e with
       | Parameter _-> assert false
       | Program _ -> assert false
-      | Obligation (loc, expl, id, s) -> 
-	  print_obligation fmt loc expl id s.Env.scheme_type
+      | Obligation (loc, is_lemma, expl, id, s) -> 
+	  print_obligation fmt loc is_lemma expl id s.Env.scheme_type
       | Logic (id, t) -> print_logic fmt id t
       | Axiom (id, p) -> print_axiom fmt id p
       | Predicate (id, p) -> print_predicate fmt id p
@@ -420,8 +424,8 @@ struct
   let reprint_element fmt = function
     | Parameter _ -> assert false
     | Program _ -> assert false
-    | Obligation (loc, expl, id, s) -> 
-	reprint_obligation fmt loc expl id s.Env.scheme_type
+    | Obligation (loc, is_lemma, expl, id, s) -> 
+	reprint_obligation fmt loc is_lemma expl id s.Env.scheme_type
     | Logic (id, t) -> reprint_logic fmt id t
     | Axiom (id, p) -> reprint_axiom fmt id p
     | Predicate (id, p) -> reprint_predicate fmt id p
@@ -449,8 +453,8 @@ end)
 let reset = Gen.reset
 
 let push_decl = function
-  | Dgoal (loc,expl,l,s) ->
-      Gen.add_elem (Oblig, l) (Obligation (loc,expl,l,s))
+  | Dgoal (loc,is_lemma,expl,l,s) ->
+      Gen.add_elem (Oblig, l) (Obligation (loc,is_lemma,expl,l,s))
   | Dlogic (_, id, t) ->
       let id = Ident.string id in
       Gen.add_elem (Lg, rename id) (Logic (id, t))
