@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -141,14 +141,14 @@ let push_decl _vloc d =
 	
 let push_obligations vloc = 
   List.iter 
-    (fun (loc,expl,id,s) -> 
+    (fun (loc,_is_lemma,expl,id,s) -> 
       let (loc,expl,id,s) = 
 	if pruning_hyp_v != -1 then 
 	  Hypotheses_filtering.reduce (loc, expl, id, s) declarationQueue
 	else
 	  (loc, expl, id, s)
       in
-      push_decl vloc (Dgoal(loc, expl, id, generalize_sequent s))
+      push_decl vloc (Dgoal(loc, false, expl, id, generalize_sequent s))
     ) 
 
 
@@ -195,8 +195,8 @@ let output is_last fwe =
 	  (* output project, used by GWhy/Coq column *)
 	  Options.gui_project := Some(Pretty.output_project fwe)
 *)
-    | Ergo -> Pretty.output_file (fwe ^ "_why.why")  
-    | Why -> Pretty.output_file (fwe ^ "_why.why") 
+    | Ergo -> Pretty.output_file ~ergo:true (fwe ^ "_why.why")  
+    | Why -> Pretty.output_file ~ergo:false (fwe ^ "_why.why") 
     | Why3 -> Why3.output_file fwe
     | MultiWhy -> Pretty.output_files fwe
     | WhyProject -> ignore(Pretty.output_project fwe)
@@ -559,14 +559,14 @@ let rec interp_decl ?(_prelude=false) d =
 	let f = generalize_function_def (pl,ty,e) in
 	push_decl ("","",Loc.dummy_floc) 
 	  (Dfunction_def (Loc.extract loc, id, f))
-    | Axiom (loc, id, p) ->
+    | Goal(loc, KAxiom, id, p) ->
 	let env = Env.empty_logic () in
 	let p = Ltyping.predicate lab env p in
 	let p = generalize_predicate p in
 	push_decl ("","",Loc.dummy_floc) 
           (Daxiom (Loc.extract loc, Ident.string id, p))
 
-    | Goal (loc, id, p) ->
+    | Goal(loc, kind, id, p) ->
 	let env = Env.empty_logic () in
 	let p = Ltyping.predicate lab env p in
 	let s = ([], p) in
@@ -579,7 +579,8 @@ let rec interp_decl ?(_prelude=false) d =
 	  { lemma_or_fun_name = Ident.string id;
 	    behavior = "";
 	    vc_loc = l;
-	    vc_kind = EKLemma;
+	    vc_kind = if kind = KLemma then EKLemma else EKCheck;
+            vc_label = None;
 	  }
 	in
 	let (l,xpl,id,s) = 
@@ -591,7 +592,7 @@ let rec interp_decl ?(_prelude=false) d =
 	in
 	let s= generalize_sequent s in 
 	let dg = 
-	  Dgoal (l, xpl, id, s) 
+	    Dgoal (l, kind = KLemma, xpl, id, s) 
 	in
 	let ids = id in
 	let vloc =
