@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -55,8 +55,8 @@ let elem_q = Queue.create ()
 let reset () = Queue.clear elem_q
 
 let push_decl = function
-  | Dgoal (loc, expl, id, s) -> 
-      Queue.add (Obligation (loc, expl, id, s.Env.scheme_type)) elem_q
+  | Dgoal (loc, is_lemma, expl, id, s) -> 
+      Queue.add (Obligation (loc, is_lemma, expl, id, s.Env.scheme_type)) elem_q
   | Dlogic (_, id, t) -> Queue.add (Logic (Ident.string id, t)) elem_q
   | Daxiom (_, id, p) -> Queue.add (Axiom (id, p)) elem_q
   | Dpredicate_def (_, id, p) -> 
@@ -112,8 +112,10 @@ let prefix_id id =
   else if id == t_add_int then "int_add"
   else if id == t_sub_int then "int_sub"
   else if id == t_mul_int then "int_mul"
+(*
   else if id == t_div_int then assert false (* TODO *)
   else if id == t_mod_int then assert false (* TODO *)
+*)
   else if id == t_neg_int then "int_neg"
   (* real ops *)
   else if id == t_add_real then "real_add"
@@ -142,10 +144,12 @@ let rec print_term fmt t =
   and print2 fmt = function
     | Tapp (id, [a; b], _) when id == t_mul_int || id == t_mul_real ->
 	fprintf fmt "%a *@ %a" print2 a print3 b
-    | Tapp (id, [a; b], _) when id == t_div_int || id == t_div_real ->
+    | Tapp (id, [a; b], _) when (* id == t_div_int || *) id == t_div_real ->
 	fprintf fmt "%a /@ %a" print2 a print3 b
+(*
     | Tapp (id, [a; b], _) when id == t_mod_int ->
 	fprintf fmt "%a mod %a" print2 a print3 b
+*)
     | t -> 
 	print3 fmt t
   and print3 fmt = function
@@ -292,7 +296,7 @@ let rec print_thesis fmt = function
   | Pand (_, _, t1, t2) -> fprintf fmt "%a@ %a" print_thesis t1 print_thesis t2
   | t -> fprintf fmt "@[thus %a@];" print_predicate t
 
-let reprint_obligation fmt loc _expl id s =
+let reprint_obligation fmt loc _is_lemma _expl id s =
   let s = s.Env.scheme_type in
   fprintf fmt "@[ :: %a @]@\n" (Loc.report_obligation_position ~onlybasename:true) loc;
   fprintf fmt "@[ (*Why goal*) theorem %s:@\n @[%a@]@]@\n" id print_sequent s
@@ -300,8 +304,8 @@ let reprint_obligation fmt loc _expl id s =
   fprintf fmt "@[ :: %a @]@\n@\n" Util.print_explanation expl
   *)
 
-let print_obligation fmt loc expl id s =
-  reprint_obligation fmt loc expl id s;
+let print_obligation fmt loc is_lemma expl id s =
+  reprint_obligation fmt loc is_lemma expl id s;
   let t = snd s.Env.scheme_type in
   fprintf fmt "@[  :: FILL PROOF HERE@\n  @[%a@]@]@\n end;@\n" print_thesis t
 
@@ -329,7 +333,8 @@ struct
     begin match e with
       | Parameter _ -> assert false
       | Program _ -> assert false
-      | Obligation (loc, expl, id, s) -> print_obligation fmt loc expl id s
+      | Obligation (loc, is_lemma, expl, id, s) -> 
+	  print_obligation fmt loc is_lemma expl id s
       | Logic (id, t) -> print_logic fmt id t
       | Axiom (id, p) -> print_axiom fmt id p
       | Predicate _ -> assert false (*TODO*)
@@ -343,7 +348,8 @@ struct
   let reprint_element fmt = function
     | Parameter _ -> assert false
     | Program _ -> assert false
-    | Obligation (loc, expl, id, s) -> reprint_obligation fmt loc expl id s
+    | Obligation (loc, is_lemma, expl, id, s) -> 
+	reprint_obligation fmt loc is_lemma expl id s
     | Logic (id, t) -> reprint_logic fmt id t
     | Axiom (id, p) -> reprint_axiom fmt id p
     | Predicate _ -> assert false (*TODO*)
@@ -384,7 +390,8 @@ end)
 let reset = Gen.reset
 
 let push_obligations = 
-  List.iter (fun (loc,expl,l,s) -> Gen.add_elem (Oblig, l) (Obligation (loc,expl,l,s)))
+  List.iter (fun (loc,expl,l,s) -> Gen.add_elem (Oblig, l) 
+	       (Obligation (loc,false,expl,l,s)))
 
 let push_parameter id v =
   Gen.add_elem (Param, id) (Parameter (id,v))
