@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 (*s General options *)
@@ -49,8 +49,8 @@ val ocaml_annot : bool
 val ocaml_externals : bool
 
 val explain_vc : bool
-val locs_table : 
-  (string, (string * int * int * int * (string * Rc.rc_value) list)) 
+val locs_table :
+  (string, (string * int * int * int * (string * Rc.rc_value) list))
      Hashtbl.t
 
 val wol : bool
@@ -93,16 +93,18 @@ val prune_context : bool
 val prune_get_depths : bool
 val pruning_hyp_considere_arith_comparison_as_special_predicate : bool
 (* FIN de Heuristiques en test *)
+(*
 val modulo : bool
+*)
 
 val phantom_types : (string,unit) Hashtbl.t
 
 type expanding = All | Goal | NoExpanding
 val defExpanding : expanding
-val get_type_expanding : unit -> expanding 
+val get_type_expanding : unit -> expanding
 
-type encoding = 
-  | NoEncoding | Predicates | Stratified | Recursive | Monomorph 
+type encoding =
+  | NoEncoding | Predicates | Stratified | Recursive | Monomorph
   | SortedStratified |MonoInst
 val get_types_encoding : unit -> encoding
 val set_types_encoding : encoding -> unit
@@ -125,7 +127,7 @@ val termination : termination
 
 type coq_version = V7 | V8 | V81
 
-type prover = 
+type prover =
   | Coq of coq_version | Pvs | HolLight | Mizar | Harvey | Simplify | CVCLite
   | SmtLib | Isabelle | Hol4 | Gappa | Zenon | Z3
   | Ergo | Why | MultiWhy | Why3 | Dispatcher | WhyProject
@@ -135,6 +137,7 @@ val prover : (* ?ignore_gui:bool  -> *) unit -> prover
 val valid : bool
 val coq_tactic : string option
 val coq_preamble : string
+val coq_use_dp: bool
 
 val pvs_preamble : string
 
@@ -172,7 +175,7 @@ val out_file_exists :  string -> bool
 
 val lib_file : string -> string
 
-val lib_dir : string 
+val lib_dir : string
 
 (*s Files given on the command line *)
 
@@ -185,7 +188,7 @@ val gui_project : Project.t option ref
 val lib_files_to_load : string list
 
 (*
-Local Variables: 
+Local Variables:
 compile-command: "unset LANG; make -j -C .. bin/why.byte"
-End: 
+End:
 *)
