@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -41,6 +41,8 @@ open Logic_decl
 
 let reset = Encoding.reset
 
+let ergo = ref false
+
 let push_decl ?(ergo=false) d = 
   if ergo
   then Encoding.push ~encode_preds:false ~encode_funs:false d
@@ -49,7 +51,10 @@ let push_decl ?(ergo=false) d =
 
 let iter = Encoding.iter
 
-let ident = Ident.print
+let ident fmt id = 
+  let s = Ident.string id in
+  let s = if s = "farray" then "why__farray" else s in (* Alt-ergo keyword *)
+  pp_print_string fmt s
 
 let type_vars = Hashtbl.create 17
 
@@ -96,10 +101,20 @@ let rec term fmt = function
       fprintf fmt "(%a - %a)" term t1 term t2
   | Tapp (id, [t1; t2], _) when id == t_mul_int || id == t_mul_real ->
       fprintf fmt "(%a * %a)" term t1 term t2
-  | Tapp (id, [t1; t2], _) when id == t_div_int || id == t_div_real ->
-      fprintf fmt "(%a / %a)" term t1 term t2
+(*
+  | Tapp (id, [t1; t2], _) when id == t_div_int ->
+      if !ergo then
+        fprintf fmt "computer_div(%a,%a)" term t1 term t2
+      else
+        fprintf fmt "(%a / %a)" term t1 term t2
+*)
+(*
   | Tapp (id, [t1; t2], _) when id == t_mod_int ->
-      fprintf fmt "(%a %% %a)" term t1 term t2
+      if !ergo then
+        fprintf fmt "computer_mod(%a,%a)" term t1 term t2
+      else
+        fprintf fmt "(%a %% %a)" term t1 term t2
+*)
   | Tapp (id, [t1], _) when id == t_neg_int || id == t_neg_real ->
       fprintf fmt "(-%a)" term t1
   | Tapp (id, tl, _) -> 
@@ -271,13 +286,25 @@ let decl fmt d =
   | Daxiom (_, id, p) ->
       let p = specialize p in
       fprintf fmt "@[<hov 2>axiom %s:@ %a@]" id predicate p
-  | Dgoal (_, _expl, id, sq) ->
+  | Dgoal (_, is_lemma, _, id, sq) ->
       let sq = specialize sq in
-      fprintf fmt "@[<hov 2>goal %s:@\n%a@]" id sequent sq
+      if !ergo then
+	begin
+	  fprintf fmt "@[<hov 2>goal %s:@\n%a@]" id sequent sq;
+	  if is_lemma then
+	    fprintf fmt "@\n@\n@[<hov 2>axiom %s_as_axiom:@\n%a@]" id sequent sq
+	end
+      else
+	fprintf fmt "@[<hov 2>%s %s:@\n%a@]" 
+	  (if is_lemma then "lemma" else "goal")
+	  id sequent sq
 
 let decl fmt d = fprintf fmt "@[%a@]@\n@\n" decl d
 
-let print_file fmt = iter (decl fmt) 
+let print_file ~ergo:b fmt = 
+  ergo := b;
+  iter (decl fmt);
+  ergo := false
 
 let print_trace fmt id expl =
   fprintf fmt "[%s]@\n" id;
@@ -287,11 +314,11 @@ let print_trace fmt id expl =
 let print_traces fmt =
   iter
     (function
-       | Dgoal (_loc, expl, id, _) -> print_trace fmt id ((*loc,*)expl)
+       | Dgoal (_loc, _, expl, id, _) -> print_trace fmt id ((*loc,*)expl)
        | _ -> ())
 
-let output_file f =
-  print_in_file print_file (Options.out_file f)
+let output_file ~ergo f =
+  print_in_file (print_file ~ergo) (Options.out_file f)
 (* cannot work as is, pb with temp files
   if explain_vc && not ergo then 
     print_in_file print_traces (Options.out_file (f ^ ".xpl"))
@@ -304,7 +331,7 @@ let output_files f =
     (fun ctxfmt ->
        iter 
 	 (function 
-	    | Dgoal (_loc,expl,id,_) as d -> 
+	    | Dgoal (_loc,_,expl,id,_) as d -> 
 		incr po;		
 		let fpo = f ^ "_po" ^ string_of_int !po ^ ".why" in
 		print_in_file (fun fmt -> decl fmt d) fpo;
@@ -320,7 +347,7 @@ let push_or_output_decl =
   let po = ref 0 in 
   function d ->
     match d with
-      | Dgoal (_loc,expl,id,_) as d -> 
+      | Dgoal (_loc,_is_lemma,expl,id,_) as d -> 
 	  incr po;
 	  let fpo = Options.out_file (id ^ ".why") in
 	  print_in_file (fun fmt -> decl fmt d) fpo;
@@ -339,7 +366,7 @@ let output_project f =
     (fun ctxfmt ->
        iter 
 	 (function 
-	    | Dgoal (_,e,_id,_) as d -> 
+	    | Dgoal (_,_is_lemma,e,_id,_) as d -> 
 		incr po;
 		let fpo = f ^ "_po" ^ string_of_int !po ^ ".why" in
 		print_in_file (fun fmt -> decl fmt d) fpo;
