@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -172,10 +172,12 @@ let print_term fmt t =
 	fprintf fmt "@[<hov 2>%a *@ %a@]" print2 a print3 b
     | Tapp (id, [a;b], _) when id == t_div_real ->
 	fprintf fmt "@[<hov 2>%a /@ %a@]" print2 a print3 b
+(*
     | Tapp (id, [a;b], _) when id == t_div_int ->
 	fprintf fmt "(@[div(%a,%a)@])" print0 a print0 b
     | Tapp (id, [a;b], _) when id == t_mod_int ->
 	fprintf fmt "(@[mod(%a,%a)@])" print0 a print0 b
+*)
     | t ->
 	print3 fmt t
   and print3 fmt = function
@@ -391,7 +393,7 @@ let print_function_def fmt id (bl,t,e) =
     ident id (print_list comma print_logic_binder) bl 
     print_pure_type t print_term e
     
-let print_obligation fmt (loc,_expl,id,s) =
+let print_obligation fmt (loc,_is_lemma,_expl,id,s) =
   fprintf fmt "  @[%% %a @]@\n" (Loc.report_obligation_position ~onlybasename:true) loc;
   fprintf fmt "  @[<hov 2>%a: LEMMA@\n" idents id;
   print_sequent fmt s;
@@ -412,7 +414,7 @@ let print_scheme l =
 
 let tvar_so_far = ref 0
 
-let print_goal fmt (loc, expl, id, s) =
+let print_goal fmt (loc, is_lemma, expl, id, s) =
   let n = Vset.cardinal s.scheme_vars in
   if n > !tvar_so_far then begin
     fprintf fmt "  ";
@@ -424,7 +426,7 @@ let print_goal fmt (loc, expl, id, s) =
   end;
   let l,s = Env.specialize_sequent s in
   print_scheme l;
-  print_obligation fmt (loc,expl,id,s)
+  print_obligation fmt (loc,is_lemma,expl,id,s)
 
 let print_logic_scheme fmt id s =
   let l,t = Env.specialize_logic_type s in
@@ -474,7 +476,7 @@ let output_elem fmt = function
   | Dinductive_def(_loc, ident, inddef) -> print_inductive_def fmt ident inddef
   | Dfunction_def (_loc, id, d) -> print_function_def fmt id d.scheme_type
   | Daxiom (_loc, id, p) -> print_axiom fmt id p.scheme_type
-  | Dgoal (loc, expl, id, s) -> print_goal fmt (loc, expl, id, s)
+  | Dgoal (loc, is_lemma, expl, id, s) -> print_goal fmt (loc, is_lemma, expl, id, s)
 
 module ArMap = struct
 
@@ -520,7 +522,7 @@ type pvs_theories = {
   decls : (string * logic_type scheme) ArMap.t;
   defs : (string * def) Queue.t;
   axioms : (string * predicate scheme) ArMap.t;
-  goals : (loc * Logic_decl.vc_expl * string * sequent scheme) Queue.t;
+  goals : (loc * bool * Logic_decl.vc_expl * string * sequent scheme) Queue.t;
   mutable poly : bool;
 }
 
@@ -553,8 +555,8 @@ let sort_theory () =
 	poly s; Queue.add (Ident.string id, DefFunction s) th.defs
     | Daxiom (_, id, s) -> 
 	poly s; ArMap.add_scheme s (id,s) th.axioms
-    | Dgoal (loc, expl, id, s) -> 
-	Queue.add (loc,expl,id,s) th.goals
+    | Dgoal (loc, is_lemma, expl, id, s) -> 
+	Queue.add (loc,is_lemma,expl,id,s) th.goals
   in
   Queue.iter sort queue;
   th
