@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -62,9 +62,11 @@ let prefix id =
   else if id == t_add_int then "+"
   else if id == t_sub_int then "-"
   else if id == t_mul_int then "*"
+(*
   else if id == t_div_int then "div_int"
   else if id == t_mod_int then
     if Options.modulo then "%" else "modulo"
+*)
   else if id == t_neg_int then "-"
   (* real ops *)
   else if id == t_add_real then "+"
@@ -302,11 +304,22 @@ let output_sequent fmt (hyps,concl) =
   in
   print_seq fmt hyps
 
-let print_obligation fmt loc _o s =
+let print_obligation fmt loc _is_lemma _o s =
   fprintf fmt "@[:formula@\n";
   fprintf fmt "  @[;; %a@]@\n" Loc.gen_report_line loc;
   fprintf fmt "  @[(not@ %a)@]" output_sequent s;
   fprintf fmt "@]@\n@\n"
+(* 
+
+   useless since goals are splitted
+   (moreover, may trigger a bug with Z3: proves the lemma using the aussmption given after)
+
+  if is_lemma then begin
+    fprintf fmt "@[;; %s as axiom@]@\n" o;
+    fprintf fmt " @[<hov 2>:assumption@ %a@]" output_sequent s;
+    fprintf fmt "@]@\n@\n"
+  end
+*)
 
 let push_decl d = Encoding.push d
 
@@ -355,7 +368,8 @@ let output_elem fmt = function
       print_function_def fmt (Ident.string id) d.scheme_type
 *)
   | Daxiom (_loc, id, p) -> print_axiom fmt id p.scheme_type
-  | Dgoal (loc, _expl, id, s) -> print_obligation fmt loc id s.Env.scheme_type
+  | Dgoal (loc, is_lemma, _expl, id, s) -> 
+      print_obligation fmt loc is_lemma id s.Env.scheme_type
 
 
 
@@ -385,10 +399,12 @@ let output_file ?logic fname =
   end;
   fprintf fmt "  :extrasorts (Unit)@\n";
   fprintf fmt "  :extrafuns ((tt Unit))@\n";
+(*
   fprintf fmt "  :extrafuns ((div_int Int Int Int))@\n";
   if not modulo then begin
     fprintf fmt "  :extrafuns ((modulo Int Int Int))@\n";
   end;
+*)
   iter (output_elem fmt);
 
   (* end of smtlib file *)
