@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -141,7 +141,10 @@ let type_neq = type_prim t_neq_int_ t_neq_real_ t_neq_bool_ t_neq_unit_
 
 let type_num idint idreal loc = function
   | PureType pt -> begin match normalize_pure_type pt with
-      | PTint -> idint
+      | PTint -> 
+          if idint == t_div_real_ then
+            expected_real loc
+          else idint
       | PTreal -> idreal
       | _ -> expected_num loc
     end
@@ -154,7 +157,7 @@ let type_ge = type_num t_ge_int_ t_ge_real_
 let type_add = type_num t_add_int t_add_real
 let type_sub = type_num t_sub_int t_sub_real
 let type_mul = type_num t_mul_int t_mul_real
-let type_div = type_num t_div_int_ t_div_real_
+let type_div = type_num t_div_real_ t_div_real_
 let type_neg = type_num t_neg_int t_neg_real
 
 let type_poly id =
@@ -538,11 +541,11 @@ let rec typef ?(userlabel="") lab env expr =
 		  let t_a = typef lab env a in
 		  let eq = type_poly x a.ploc (result_type t_a) in
 		  { f with pdesc = Svar eq }
-	      | [] -> 
-		  assert false 
+	      | [] ->
+		  assert false
 		  (* the parser ensures the presence of an argument *)
 	    end
-	| _ -> 
+	| _ ->
 	    f
       in
       (* 2. typing the function f *)
@@ -603,6 +606,7 @@ let rec typef ?(userlabel="") lab env expr =
 		expected_type a.ploc (result_type t_a) tx;
 		begin match t_a with
 		(* argument is pure: it is substituted *)
+(***
    	        | { desc = Expression ta } when post t_a = None ->
 		    let kapp = type_c_subst_oldify env x ta kapp in
 		    let _,_,papp,_ = decomp_type_c kapp in
@@ -626,6 +630,7 @@ let rec typef ?(userlabel="") lab env expr =
 				  ~post:kapp.t_post (AppTerm (t_f, ta, kapp))))
 		    in
 		    loop_args t_f (result_type t_f) ra
+***)
  	        (* otherwise we transform into [let v = arg in (f v)] *)
 		| _ ->
 		    let _,eapp,_,_ = decomp_type_c kapp in
