@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 
 
@@ -1074,6 +1074,11 @@ and print_phandler fmt = function
 
 let print_external fmt b = if b then fprintf fmt "external "
 
+let str_of_goal_kind = function
+  | KAxiom -> "axiom"
+  | KLemma -> "lemma"
+  | KGoal -> "goal"
+
 let print_decl fmt = function
   | Include (_,s) -> fprintf fmt "include \"%S\"" s 
   | Program (_,id, p) -> fprintf fmt "let %a = %a" Ident.print id print_ptree p
@@ -1083,10 +1088,8 @@ let print_decl fmt = function
   | Logic (_, e, ids, _lt) -> 
       fprintf fmt "%alogic %a : <...>" print_external e 
 	(print_list comma Ident.print) ids
-  | Axiom (_, id, _p) ->
-      fprintf fmt "axiom %a : <...>" Ident.print id
-  | Goal (_, id, _p) ->
-      fprintf fmt "assert %a : <...>" Ident.print id
+  | Goal (_, k, id, _p) ->
+      fprintf fmt "%s %a : <...>" (str_of_goal_kind k) Ident.print id
   | Predicate_def (_, id, _, _) ->
       fprintf fmt "predicate %a <...>" Ident.print id
   | Inductive_def (_, id, _, _) ->
@@ -1267,7 +1270,6 @@ let print_loc_predicate fmt (loc,p) =
 	  Loc.gen_report_position loc print_predicate p
 *)
   
-
 let print_decl fmt = function
   | Dtype (_, s, _) ->
       fprintf fmt "type %s" (Ident.string s)
@@ -1291,9 +1293,10 @@ let print_decl fmt = function
   | Daxiom (_, s, pred_sch) ->
       fprintf fmt "axiom %s : %a" s 
 	print_predicate pred_sch.Env.scheme_type
-  | Dgoal (_loc, expl, s, seq_sch) -> 
+  | Dgoal (_loc, is_lemma, expl, s, seq_sch) -> 
       let (cel, pred) = seq_sch.Env.scheme_type in
-      fprintf fmt "goal %s (%a) : %a" s
+      fprintf fmt "%s %s (%a) : %a" 
+	(if is_lemma then "lemma" else "goal") s
 	(print_list comma 
 	   (fun fmt t -> match t with 
 	     Cc.Svar (id, pt) -> 
