@@ -1,33 +1,33 @@
-(********************************************************************************)
-(*                                                                              *)
-(*  The Why platform for program certification                                  *)
-(*                                                                              *)
-(*  Copyright (C) 2002-2010                                                     *)
-(*                                                                              *)
-(*    Yannick MOY, Univ. Paris-sud 11                                           *)
-(*    Jean-Christophe FILLIATRE, CNRS                                           *)
-(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                                 *)
-(*    Romain BARDOU, Univ. Paris-sud 11                                         *)
-(*    Thierry HUBERT, Univ. Paris-sud 11                                        *)
-(*                                                                              *)
-(*  Secondary contributors:                                                     *)
-(*                                                                              *)
-(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)                *)
-(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)              *)
-(*    Sylvie BOLDO, INRIA                 (floating-point support)              *)
-(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hypothesis pruning)  *)
-(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                             *)
-(*                                                                              *)
-(*  This software is free software; you can redistribute it and/or              *)
-(*  modify it under the terms of the GNU Lesser General Public                  *)
-(*  License version 2.1, with the special exception on linking                  *)
-(*  described in file LICENSE.                                                  *)
-(*                                                                              *)
-(*  This software is distributed in the hope that it will be useful,            *)
-(*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *)
-(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        *)
-(*                                                                              *)
-(********************************************************************************)
+(**************************************************************************)
+(*                                                                        *)
+(*  The Why platform for program certification                            *)
+(*                                                                        *)
+(*  Copyright (C) 2002-2010                                               *)
+(*                                                                        *)
+(*    Jean-Christophe FILLIATRE, CNRS                                     *)
+(*    Claude MARCHE, INRIA & Univ. Paris-sud 11                           *)
+(*    Yannick MOY, Univ. Paris-sud 11                                     *)
+(*    Romain BARDOU, Univ. Paris-sud 11                                   *)
+(*    Thierry HUBERT, Univ. Paris-sud 11                                  *)
+(*                                                                        *)
+(*  Secondary contributors:                                               *)
+(*                                                                        *)
+(*    Nicolas ROUSSET, Univ. Paris-sud 11 (on Jessie & Krakatoa)          *)
+(*    Ali AYAD, CNRS & CEA Saclay         (floating-point support)        *)
+(*    Sylvie BOLDO, INRIA                 (floating-point support)        *)
+(*    Jean-Francois COUCHOT, INRIA        (sort encodings, hyps pruning)  *)
+(*    Mehdi DOGGUY, Univ. Paris-sud 11    (Why GUI)                       *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU Lesser General Public            *)
+(*  License version 2.1, with the special exception on linking            *)
+(*  described in file LICENSE.                                            *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(**************************************************************************)
 
 (* Why code obfuscator *)
 
@@ -163,8 +163,6 @@ let rec lexpr m fmt p =
       fprintf fmt "(@[%a ->@ %a@])" lexprm a lexprm b
   | PPinfix (a, PPiff, b) -> 
       fprintf fmt "(@[%a <->@ %a@])" lexprm a lexprm b
-  | PPinfix (a, PPmod, b) -> 
-      fprintf fmt "(@[%a %%@ %a@])" lexprm a lexprm b
   | PPinfix (a, PPdiv, b) -> 
       fprintf fmt "(@[%a /@ %a@])" lexprm a lexprm b
   | PPinfix (a, PPmul, b) -> 
@@ -316,16 +314,18 @@ let opt_variant m fmt = function
   | Some var -> fprintf fmt "{ variant %a }" (variant m) var
 
 let is_binop id = 
-  id == t_add || id == t_sub || id == t_mul || id == t_div
-  || id == t_mod_int || id == t_eq || id == t_neq
+  id == t_add || id == t_sub || id == t_mul || id == t_div_real
+  (* || id == t_mod_int *) || id == t_eq || id == t_neq
   || id == t_lt || id == t_le || id == t_gt || id == t_ge
 
 let binop id = 
   if id == t_add then "+"
   else if id == t_sub then "-"
   else if id == t_mul then "*"
-  else if id == t_div then "/"
+  else if id == t_div_real then "/"
+(*
   else if id == t_mod_int then "%"
+*)
   else if id == t_eq then "="
   else if id == t_neq then "<>"
   else if id == t_lt then "<"
@@ -435,6 +435,11 @@ let logic_type fmt = function
   | PFunction (ptl, pt) -> 
       fprintf fmt "%a -> %a" (print_list comma ppure_type) ptl ppure_type pt
 
+let str_of_goal_kind = function
+  | KAxiom -> "axiom"
+  | KLemma -> "lemma"
+  | KGoal -> "goal"
+
 let decl fmt = function
   | Include (_,s) ->
       fprintf fmt "@[<hov 2>include@ \"%S\"@]" s
@@ -453,12 +458,10 @@ let decl fmt = function
       List.iter rename_global ids;
       fprintf fmt "%alogic %a : %a" print_external e 
 	(print_list comma gident) ids logic_type lt
-  | Axiom (_, id, p) ->
+  | Goal (_, k, id, p) ->
       rename_global id;
-      fprintf fmt "axiom %a : %a" gident id (lexpr M.empty) p
-  | Goal (_, id, p) ->
-      rename_global id;
-      fprintf fmt "goal %a : %a" gident id (lexpr M.empty) p
+      fprintf fmt "%s %a : %a" (str_of_goal_kind k) 
+        gident id (lexpr M.empty) p
   | Predicate_def (_, id, bl, p) ->
       rename_global id;
       let m = List.fold_left rename M.empty (List.map (fun (_,x,_) -> x) bl) in
